@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::Author::OpusVL;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
  
 use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
@@ -23,7 +23,7 @@ sub configure {
     ));
     $self->add_bundle('@Filter', {
         '-bundle' => '@Basic',
-        '-remove' => [ 'GatherDir', 'UploadToCPAN' ],
+        '-remove' => [ 'GatherDir', 'UploadToCPAN', 'TestRelease' ],
     });
 
     $self->add_plugins(qw(
@@ -38,8 +38,14 @@ sub configure {
         RewriteVersion
         NextRelease
         Repository
-        PodWeaver
     ),
+        [ Encoding => 
+            CommonBinaryFiles => {
+                match => '\.(png|jpg|db)$',
+                encoding => 'bytes'
+        } ],
+        # Don't try to weave scripts. They have their own POD.
+        [ PodWeaver => { finder => ':InstallModules' } ],
         [ 'Git::Commit' =>
             CommitGeneratedFiles => { 
                 allow_dirty => [ qw/dist.ini Changes cpanfile LICENSE/ ]
